==> jc-1.4.0.tar.gz: java/security/SecurityPermission.h <==
// public final class java.security.SecurityPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 6de4d0aa7d302f3f java_security_SecurityPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_security_SecurityPermission_H_
#define _JC_java_security_SecurityPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_SecurityPermission$sub_refs	_jc_java_security_SecurityPermission$sub_refs;
typedef struct _jc_java_security_SecurityPermission$sub_nonrefs	_jc_java_security_SecurityPermission$sub_nonrefs;
typedef struct _jc_java_security_SecurityPermission$refs	_jc_java_security_SecurityPermission$refs;
typedef struct _jc_java_security_SecurityPermission$nonrefs	_jc_java_security_SecurityPermission$nonrefs;
typedef struct _jc_java_security_SecurityPermission$object	_jc_java_security_SecurityPermission$object;

typedef struct _jc_java_security_SecurityPermission$fields_struct	_jc_java_security_SecurityPermission$fields_struct;
typedef const struct _jc_java_security_SecurityPermission$vmethods	_jc_java_security_SecurityPermission$vmethods;
typedef const struct _jc_java_security_SecurityPermission$vtable	_jc_java_security_SecurityPermission$vtable;
typedef const struct _jc_java_security_SecurityPermission$vtype	_jc_java_security_SecurityPermission$vtype;

// Class fields structure
struct _jc_java_security_SecurityPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_SecurityPermission$fields_struct _jc_java_security_SecurityPermission$class_fields;

// Constructors
extern void _jc_java_security_SecurityPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_SecurityPermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_security_SecurityPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_security_SecurityPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_security_SecurityPermission$vmethods {
};

// Vtable
struct _jc_java_security_SecurityPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_security_SecurityPermission$vmethods	java_security_SecurityPermission;
};

// Vtype
struct _jc_java_security_SecurityPermission$vtype {
	_jc_type			type;
	_jc_java_security_SecurityPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SecurityPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_SecurityPermission$refs {
    _jc_java_security_SecurityPermission$sub_refs	java_security_SecurityPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SecurityPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SecurityPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_security_SecurityPermission$sub_nonrefs	java_security_SecurityPermission;
};

// Object instance structure
struct _jc_java_security_SecurityPermission$object {
	_jc_java_security_SecurityPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SecurityPermission$vtype	*vtype;
	_jc_java_security_SecurityPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SecurityPermission$vtype _jc_java_security_SecurityPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SecurityPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SecurityPermission$class_object;

#endif	/* _JC_java_security_SecurityPermission_H_ */

==> jc-1.4.6.tar.gz: java/security/SecurityPermission.h <==
// public final class java.security.SecurityPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 6de4d0aa7d302f3f java_security_SecurityPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_security_SecurityPermission_H_
#define _JC_java_security_SecurityPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_SecurityPermission$sub_refs	_jc_java_security_SecurityPermission$sub_refs;
typedef struct _jc_java_security_SecurityPermission$sub_nonrefs	_jc_java_security_SecurityPermission$sub_nonrefs;
typedef struct _jc_java_security_SecurityPermission$refs	_jc_java_security_SecurityPermission$refs;
typedef struct _jc_java_security_SecurityPermission$nonrefs	_jc_java_security_SecurityPermission$nonrefs;
typedef struct _jc_java_security_SecurityPermission$object	_jc_java_security_SecurityPermission$object;

typedef struct _jc_java_security_SecurityPermission$fields_struct	_jc_java_security_SecurityPermission$fields_struct;
typedef const struct _jc_java_security_SecurityPermission$vmethods	_jc_java_security_SecurityPermission$vmethods;
typedef const struct _jc_java_security_SecurityPermission$vtable	_jc_java_security_SecurityPermission$vtable;
typedef const struct _jc_java_security_SecurityPermission$vtype	_jc_java_security_SecurityPermission$vtype;

// Class fields structure
struct _jc_java_security_SecurityPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_SecurityPermission$fields_struct _jc_java_security_SecurityPermission$class_fields;

// Constructors
extern void _jc_java_security_SecurityPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_SecurityPermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_SecurityPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_security_SecurityPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_SecurityPermission$vmethods {
};

// Vtable
struct _jc_java_security_SecurityPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_security_SecurityPermission$vmethods	java_security_SecurityPermission;
};

// Vtype
struct _jc_java_security_SecurityPermission$vtype {
	_jc_type			type;
	_jc_java_security_SecurityPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SecurityPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_SecurityPermission$refs {
    _jc_java_security_SecurityPermission$sub_refs	java_security_SecurityPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SecurityPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SecurityPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_security_SecurityPermission$sub_nonrefs	java_security_SecurityPermission;
};

// Object instance structure
struct _jc_java_security_SecurityPermission$object {
	_jc_java_security_SecurityPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SecurityPermission$vtype	*vtype;
	_jc_java_security_SecurityPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SecurityPermission$vtype _jc_java_security_SecurityPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SecurityPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SecurityPermission$class_object;

#endif	/* _JC_java_security_SecurityPermission_H_ */
